@@ -1,5 +1,6 @@
 """Helper class for work with string values"""
 
+import collections.abc
 from typing import Any, Optional
 
 
@@ -31,6 +32,8 @@ class StringUtils:
     @staticmethod
     def object_to_string(data: Any) -> str:
         """Convert various data types into their string representation."""
+        if data is None:
+            return "None"
         if isinstance(data, str):
             return f"'{data}'"
         result = StringUtils._collection_to_string(data)
@@ -38,19 +41,17 @@ class StringUtils:
             return result
         if isinstance(data, bool):
             return StringUtils.bool_to_string_lower_case(data)
-        if data is None:
-            return "None"
         if hasattr(data, '__str__'):
             return str(data)
         return repr(data)
 
     @staticmethod
     def _collection_to_string(data: Any) -> Optional[str]:
-        if isinstance(data, (list, tuple)):
-            return "[" + ",".join(StringUtils.object_to_string(item) for item in data) + "]"
         if isinstance(data, dict):
             return "{" + ",".join(
                 f"{StringUtils.object_to_string(key)}: {StringUtils.object_to_string(value)}"
                 for key, value in data.items()
             ) + "}"
+        if isinstance(data, collections.abc.Iterable):
+            return "[" + ",".join(StringUtils.object_to_string(item) for item in data) + "]"
         return None
