@@ -1,7 +1,6 @@
 """Targeting Segment"""
 
 from typing import Optional
-from kameleoon.configuration.rule import Rule
 from kameleoon.data.manager.visitor import Visitor
 from kameleoon.data.manager.visitor_manager import VisitorManager
 from kameleoon.helpers.functions import enum_from_literal
@@ -16,6 +15,7 @@ from kameleoon.targeting.conditions.target_experiment_condition import TargetExp
 from kameleoon.targeting.conditions.target_personalization_condition import TargetPersonalizationCondition
 from kameleoon.targeting.conditions.targeting_condition import TargetingConditionType
 from kameleoon.targeting.conditions.visit_number_today_condition import VisitNumberTodayCondition
+from kameleoon.targeting.models import Segment
 
 
 class TargetingManager:
@@ -26,22 +26,23 @@ class TargetingManager:
         self.__visitor_manager = visitor_manager
 
     # pylint: disable=W0238
-    def check_targeting(self, visitor_code: str, campaign_id: int, rule: Rule):
+    def check_targeting(self, visitor_code: str, campaign_id: Optional[int], segment: Optional[Segment]):
         """Check if visitor is targeted for rule"""
         KameleoonLogger.debug(
-            "CALL: TargetingManager.check_targeting(visitor_code: %s, campaign_id: %s, rule: %s)",
-            visitor_code, campaign_id, rule
+            "CALL: TargetingManager.check_targeting(visitor_code: %s, campaign_id: %s, segment: %s)",
+            visitor_code, campaign_id, segment
         )
-        segment = rule.targeting_segment
         if segment is None:
             targeting: Optional[bool] = True
         else:
             visitor = self.__visitor_manager.get_visitor(visitor_code)
-            targeting = segment.check_tree(lambda type: self.__get_condition_data(type, visitor, visitor_code,
-                                                                                  campaign_id))
-        KameleoonLogger.debug("RETURN: TargetingManager.check_targeting(visitor_code: %s, campaign_id: %s, "
-                              "rule: %s) -> (targeting: %s)",
-                              visitor_code, campaign_id, rule, targeting)
+            targeting = segment.check_tree(
+                lambda type: self.__get_condition_data(type, visitor, visitor_code, campaign_id)
+            )
+        KameleoonLogger.debug(
+            "RETURN: TargetingManager.check_targeting(visitor_code: %s, campaign_id: %s, "
+            "segment: %s) -> (targeting: %s)", visitor_code, campaign_id, segment, targeting
+        )
         return targeting
 
     # pylint: disable=R0911
@@ -50,9 +51,9 @@ class TargetingManager:
         condition_type_literal: str,
         visitor: Optional[Visitor],
         visitor_code: str,
-        campaign_id: int,
+        campaign_id: Optional[int],
     ):
-        # pylint: disable=E1101,W0212
+        # pylint: disable=E1101
         KameleoonLogger.debug(
             "CALL: TargetingManager.__get_condition_data(condition_type_literal: %s, visitor, visitor_code: %s, "
             "campaign_id: %s)", condition_type_literal, visitor_code, campaign_id
@@ -72,9 +73,10 @@ class TargetingManager:
                     lambda type: self.__get_condition_data(type, visitor, visitor_code, campaign_id),
                 )
             elif condition_type == TargetingConditionType.EXCLUSIVE_EXPERIMENT:
-                condition_data = ExclusiveExperimentCondition.TargetingData(
-                    campaign_id, visitor.variations if visitor else {}, visitor.personalizations if visitor else {}
-                )
+                if campaign_id is not None:
+                    condition_data = ExclusiveExperimentCondition.TargetingData(
+                        campaign_id, visitor.variations if visitor else {}, visitor.personalizations if visitor else {}
+                    )
             elif condition_type == TargetingConditionType.VISITOR_CODE:
                 condition_data = visitor_code
             elif condition_type == TargetingConditionType.SDK_LANGUAGE:
