@@ -15,6 +15,10 @@ from kameleoon import KameleoonWSGIMiddleware
 
 sys.path.append(os.path.dirname(os.path.dirname(os.path.dirname(__file__))))
 from django.core.wsgi import get_wsgi_application
-os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'proj.settings')
 
-application = KameleoonWSGIMiddleware(get_wsgi_application(), '127.0.0.1', uuid.uuid4().hex)
+os.environ.setdefault("DJANGO_SETTINGS_MODULE", "proj.settings")
+
+from django.apps import apps
+
+kameleoon_app = apps.get_app_config("kameleoon_app")
+application = KameleoonWSGIMiddleware(get_wsgi_application(), kameleoon_app.kameleoon_client, uuid.uuid4().hex)
